%% ------------------------------------------------------------------------
% Writen for:   NTNU and Fred. Olsen
% Create by:    Marius Berg Maastad      
% 
% Aim:          Investigate the ULS and FLS design checks
%
% Subfunction:  design_loads_yield = establish the yield design loads
%               design_loads_buckling = establish the buckling design loads
%
% ------------------------------------------------------------------------


clear
close all
clc

%% Description
% Without Heave Plate
% 'worst_sea_state'

% With Heave Plate
% 'worst_sea_state_hp'

%% Set parameter
basepath = {'worst_sea_state_hp'};


%% Run Script
path = {'wind';'wave'};
for i= 1:length(path)
    loc = fullfile(basepath,path{i});   
    cd(char(loc));
    folder = dir();
    folder(1:2) = [];   
    for j = 1 : length(folder)
        if strcmp(path{i},'wind') ==1
            ts.(path{i})(j) = load(folder(j).name);
        else
            ts.(path{i})(j) = load(folder(j).name);
        end
            
    end
    cd('../../');
end


% Dimensioning of cross section
d = ts.wave(1).ls.prop.tower_bottom_diameter;
t = ts.wave(1).ls.prop.tower_bottom_wall_thickness;
%t=0.2;

A =  (pi./4) * (d^2 - (d-2*t)^2); % m^2
I = (pi/64)*(d^4 - (d-2*t)^4); % m^4
W_elastic = (I*2) / d; % m^3
Z_plastic = (d^3 - (d-2*t)^3)/6;

fact_perm(1) = 1.25;
fact_env(1) = 0.7;
fact_perm(2) = 0.9;
fact_env(2) = 1.35;

s = 0.3; % defined as 0.3, but can be smaller!



fact_mat = 1.1; % Found from DNV-RP-J101
fy = 250 *10^6; % Pa
E = ts.wave(1).ls.prop.environment_steel_E_module; % Pa
L = 87.6 - 15 + 1; %tower top pos - half column height + interface height
l = L/10; % buckling length!
poisson = 0.3;

theta = sort(-pi/2:pi/8:pi/2,'descend');




% yield check
for pp = 1:length(path)
    if strcmp(path{pp},'wind')
        var = 'wind';
    else
        var = 'wave';
    end
    for oo = 1:length(ts.wind)
        for ang = 1:length(theta)
            
            [static,sig_a,sig_m] = design_loads_yield(fact_perm,fact_env,d,t,ts,var,oo,ang,theta);

            res_y.(var)(oo).sig_sd_ts = sig_m + sig_a;
            res_y.(var)(oo).sig_sd_max(ang) = max(sig_m + sig_a);
            

        end
    end
end

for pp = 1:length(path)
    if strcmp(path{pp},'wind')
        var = 'wind';
    else
        var = 'wave';
    end
    res2_y.(var).sig_sd_max= zeros(1,length(theta));
    for i = 1:length(theta)
        for j = 1:length(ts.wind)
            res2_y.(var).sig_sd_max(i) = res2_y.(var).sig_sd_max(i) ...
                + res_y.(var)(j).sig_sd_max(i);
        end
        
        final_y.(var).sig_sd_final(i) =  res2_y.(var).sig_sd_max(i)/...
            length(ts.wave);
        check = fy / fact_mat;
        if check > final_y.(var).sig_sd_final(i)
            checks_y.(var)(i).yield_check = 'OK';
        else
            checks_y.(var)(i).yield_check = 'NOT OK';
        end
        
    end
 
end


%% Buckling check
Z_I = (l^2/(0.5*d*t))*sqrt(1-poisson^2);

C_table = [1, 0.702*Z_I, 0.5* (1 + (0.5*d /(150 *t)))^-0.5;
    1, 0.702*Z_I, 0.5* (1 + (0.5*d /(150 *t)))^-0.5;...
    5.34, 0.856*Z_I^(3/4), 0.6;];


buck_typ = {'shell';'global'};

for i = 1:3
    C(i) = C_table(i,1)*sqrt(1 + ( ( C_table(i,3)*C_table(i,2) ) / ...
        C_table(i,1) )^2 ); 
    f(i) = C(i)* ( (pi^2 *E)/(12*(1-poisson^2)) ) * (t/l)^2;
end

for pp = 1:length(path)
    if strcmp(path{pp},'wind')
        var = 'wind';
    else
        var = 'wave';
    end
    for typ = 1:length(buck_typ)
        for oo = 1:length(ts.wind)
            for ang = 1:length(theta)

                [sig_a,sig_m,tau_sd] = design_loads_buckling(fact_perm,fact_env,d,t,ts,var,oo,ang,theta);

                switch (buck_typ{typ})
                    case 'shell'
                        %% shell buckling ring stiffened (unstiffened circular cylinder) (3.4)
                        sig_j_sd =  sqrt( (sig_a + sig_m).^2 + 3.* tau_sd  );
                        res_b.(buck_typ{typ}).(var)(oo).sig_j_sd_max(ang)  = ...
                            max ( sqrt( (sig_a + sig_m).^2 + 3.* tau_sd  ) );

                        lambda_squared = ( fy ./sig_j_sd ) .* ( (sig_a./f(1) )...
                            + (sig_m./f(2) ) + (tau_sd./f(3) ) );

                        res_b.(buck_typ{typ}).(var)(oo).lambda_squared_max(ang) = max(lambda_squared);

                        fks = fy ./ (sqrt(1 + lambda_squared.^2));

                        res_b.(buck_typ{typ}).(var)(oo).fks_max(ang) = fy / ...
                            (sqrt(1 + res_b.(buck_typ{typ}).(var)(oo).lambda_squared_max(ang)^2));


                        fact_mat = 0.85 + 0.6 .*sqrt(lambda_squared);

                        res_b.(buck_typ{typ}).(var)(oo).fact_mat_max(ang) = 0.85 + 0.6 ...
                            *sqrt(res_b.(buck_typ{typ}).(var)(oo).lambda_squared_max(ang));

                        fksd = fks ./ fact_mat;

                        res_b.(buck_typ{typ}).(var)(oo).fksd_max(ang) = res_b.(buck_typ{typ}).(var)(oo).fks_max(ang)/ ...
                            res_b.(buck_typ{typ}).(var)(oo).fact_mat_max(ang);
                    
                    %% Panel ring buckling, (3.5)
                    case 'panel_ring'
                    
                    %% Column buckling, (3.8)
                     case 'global'
                         i_c = sqrt(I/A);
                         check_global = (1 * L / (i_c));
                         if check_global < ( (2.5 * E) /fy )
                             disp('No need to strengthen column buckling strength');
                             break;
                         else
                         end
                         
                    %% Error     
                    otherwise
                         disp('error');
                         return;
                        
                end
            end
        end
    end
end

for pp = 1:length(path)
    if strcmp(path{pp},'wind')
        var = 'wind';
    else
        var = 'wave';
    end
    
    for typ = 1:length(buck_typ)
        if typ ==2 
            break;
        else
        end
        res2_b.(buck_typ{typ}).sig_j_tot_ang = zeros(1,length(theta));
        res2_b.(buck_typ{typ}).fks = zeros(1,length(theta));
        res2_b.(buck_typ{typ}).fact_mat_max = zeros(1,length(theta));
        for i = 1:length(theta)
            for j = 1:length(ts.wind)
                res2_b.(buck_typ{typ}).sig_j_tot_ang(i) = res2_b.(buck_typ{typ}).sig_j_tot_ang(i) ...
                    + res_b.(buck_typ{typ}).(var)(j).sig_j_sd_max(i);
                res2_b.(buck_typ{typ}).fks(i) = res2_b.(buck_typ{typ}).fks(i) ....
                    + res_b.(buck_typ{typ}).(var)(j).fks_max(i);
                res2_b.(buck_typ{typ}).fact_mat_max(i) = res2_b.(buck_typ{typ}).fact_mat_max(i) ...
                    + res_b.(buck_typ{typ}).(var)(j).fact_mat_max(i);

            end
            final_b.(buck_typ{typ}).(var).sig_j_sd_final(i) =  res2_b.(buck_typ{typ}).sig_j_tot_ang(i)/length(ts.wave);
            final_b.(buck_typ{typ}).(var).fks(i) =  res2_b.(buck_typ{typ}).fks(i)/length(ts.wave);
            final_b.(buck_typ{typ}).(var).fact_mat_max(i) =  res2_b.(buck_typ{typ}).fact_mat_max(i)/length(ts.wave);
            check = final_b.(buck_typ{typ}).(var).fks(i) / final_b.(buck_typ{typ}).(var).fact_mat_max(i);

            if check > final_b.(buck_typ{typ}).(var).sig_j_sd_final(i)
                checks_b.(buck_typ{typ}).(var)(i).buckling_check = 'OK';
            else
                checks_b.(buck_typ{typ}).(var)(i).buckling_check = 'NOT OK';
            end

        end
    end
end




