function [sig_a,sig_m,tau_sd] = design_loads_buckling(fact_perm,fact_env,d,t,ts,var,oo,ang,theta)

A =  (pi./4) * (d^2 - (d-2*t)^2); % m^2
I = (pi/64)*(d^4 - (d-2*t)^4); % m^4
W_elastic = (I*2) / d; % m^3
Z_plastic = (d^3 - (d-2*t)^3)/6;



%% Static results 

load('worst_sea_state_static/2016-11-24_13-48-31.mat');
% Compression 
static.Nx_mean =  ls.ts.tower_base_X_force.stat.mean *...
    ones(1,length(ts.(var)(oo).ls.ts.tower_base_X_force.y))';

% Bending 
static.My_mean =  ls.ts.tower_base_Y_moment.stat.mean.*...
    ones(1,length(ts.(var)(oo).ls.ts.tower_base_X_force.y))';

static.Mz_mean = ls.ts.tower_base_Z_moment.stat.mean.*...
    ones(1,length(ts.(var)(oo).ls.ts.tower_base_X_force.y))';
% shear
static.Mx_mean = ls.ts.tower_base_X_moment.stat.mean.*...
    ones(1,length(ts.(var)(oo).ls.ts.tower_base_X_force.y))';
static.Ny_mean =  ls.ts.tower_base_Y_force.stat.mean *...
    ones(1,length(ts.(var)(oo).ls.ts.tower_base_X_force.y))';
static.Nz_mean =  ls.ts.tower_base_Z_force.stat.mean *...
    ones(1,length(ts.(var)(oo).ls.ts.tower_base_X_force.y))';

for f = 1:length(fact_perm)
    % tower axial
    sig_a(:,f) = (fact_perm(f).* static.Nx_mean + fact_env(f).*...
        ( ts.(var)(oo).ls.ts.tower_base_X_force.y - static.Nx_mean ) )./A; %Pa
    % bending
    M1(:,f) = (fact_perm(f).* static.Mz_mean +  fact_env(f).*...
        ( ts.(var)(oo).ls.ts.tower_base_Z_moment.y - static.Mz_mean ) )./W_elastic; %Pa

    M2(:,f) = (fact_perm(f).* static.My_mean +  fact_env(f).*...
        ( ts.(var)(oo).ls.ts.tower_base_Y_moment.y - static.My_mean ) )./W_elastic; %Pa
    
    % shear
    tau_t(:,f) = (fact_perm(f).* static.Mx_mean + fact_env(f).*...
        ( ts.(var)(oo).ls.ts.tower_base_X_moment.y - static.Mx_mean) )./W_elastic; % Pa torsion
    Q1(:,f) = (fact_perm(f).* static.Ny_mean + fact_env(f).*...
        ( ts.(var)(oo).ls.ts.tower_base_Y_force.y - static.Ny_mean) ) ./A; % Pa Y direction
    Q2(:,f) = (fact_perm(f).* static.Nz_mean + fact_env(f).*...
        ( ts.(var)(oo).ls.ts.tower_base_Z_force.y - static.Nz_mean) ) ./A; % Pa Y direction
    tau_q(:,f) = - Q1(:,f).*sin(theta(ang)) + Q2(:,f).*cos(theta(ang)); % Pa around the circle
    tau_sd(:,f) = sqrt(tau_t(:,f).^2) + sqrt(tau_q(:,f).^2);
    
    sig_m(:,f) = M1(:,f).*cos(theta(ang)) + M2(:,f).*sin(theta(ang)); % Pa around the circle
    

    
end
if min(sig_a(:,1)) < min(sig_a(:,2))
    sig_a = sig_a(:,1);
else
    sig_a = sig_a(:,2);
end

if min(sig_m(:,1)) < min(sig_m(:,2))
    sig_m = sig_m(:,1);
else
    sig_m = sig_m(:,2);
end

if max(tau_sd(:,1)) > max(tau_sd(:,2))
    tau_sd = tau_sd(:,1);
else
    tau_sd = tau_sd(:,2);
end

for j = 1:length(sig_a)
    if sig_a(j) < 0
        sig_a(j) = -sig_a(j);
    else
        sig_a(j) = 0;
    end
    
    if sig_m(j) < 0
        sig_m(j) = -sig_m(j);
    else
        sig_m(j) = 0;
    end
    
end




end