%% ------------------------------------------------------------------------
% Writen for:   NTNU and Fred. Olsen
% Create by:    Marius Berg Maastad      
% 
% Aim:          Calculates the fatigue damage from numerical calculations
%
% Subfunction:  tp2rfc- Create turning points in a FLS analysis
%               cc2dam_2slope - Calculate the damage, based upon S-N curves
%
% ------------------------------------------------------------------------


function ls = calcFatigue(ls)

d = [ls.prop.tower_bottom_diameter, ls.prop.tower_top_diameter];
t = [ls.prop.tower_bottom_wall_thickness, ls.prop.tower_top_wall_thickness];

A = zeros(1,2);
A(1,1) =  (pi./4) * (d(1).^2 - (d(1)-2*t(1)).^2); % for tower base m^2
A(1,2) =  (pi./4) * (d(2).^2 - (d(2)-2*t(2)).^2); % for tower top m^2

I = zeros(1,2);
I(1,1) = (pi/64)*(d(1)^4 - (d(1)-2*t(1))^4); % for tower base m^4
I(1,2) = (pi/64)*(d(2)^4 - (d(2)-2*t(2))^4); % for tower base m^4

interval = (ls.prop.sim_solver_fatigue_int_time/ls.ts.tower_base_Y_moment.dt);
My = [ls.ts.tower_base_Y_moment.y(interval+1:end), ls.ts.tower_top_Y_moment.y(interval+1:end)]; % Nm
Mz = [ls.ts.tower_base_Z_moment.y(interval+1:end), ls.ts.tower_top_Z_moment.y(interval+1:end)]; % Nm
Nx = [ls.ts.tower_base_X_force.y(interval+1:end), ls.ts.tower_top_X_force.y(interval+1:end)]; % Nm

theta= [-90,0,90];

% Stresses    
% Stress from nacelle


for alfa = 1:length(theta)
        %Tower base
        sigma_n_b = Nx(:,1)./ A(1,1); %MPa, Compression all over the cross section
        sigma_yz_b = My(:,1).*d(1).*0.5.*sind(theta(alfa))./ I(1,1)+  Mz(:,1).*d(1).*0.5.*cosd(theta(alfa))./ I(1,1);
        sigma_tb(:,alfa) = (sigma_n_b + sigma_yz_b)*10^-6;
        
        % Tower top
        sigma_n_t = Nx(:,2)./ A(1,2); %MPa, Compression all over the cross section
        sigma_yz_t = My(:,2).*d(2).*0.5.*sind(theta(alfa)) ./ I(1,2) + Mz(:,2).*d(2).*0.5.*cosd(theta(alfa))./ I(1,2);
        sigma_tt(:,alfa) = (sigma_n_t + sigma_yz_t)*10^-6;
end

Damage = zeros(2,length(theta));
dt = ls.ts.tower_base_X_moment.dt;
for n = 1:2; %1 = tower-base 2=tower-top
    for alfa = 1:length(theta);
        
        x(:,1) = 0:dt:(length(ls.ts.wave_eta_origin.y)-interval)*dt-dt;
        
        if n == 1
            x(:,2) = sigma_tb(:,alfa); 
        elseif n == 2
            x(:,2) = sigma_tt(:,alfa); 
        end
        
        [tp, ind] = dat2tp(x);  

        def.res = 'CS';
        def.asymmetric = 0;
        def.time = 0;
        [RFC,RFC1,res,def] = tp2rfc(tp,def); %% input: turning points

        % calculate damage
        k           = 0.2; 
        tref        = 0.025;
        thk         = 0.045;
        stresslim   = 52.63; % table 2-1 DNV RP -C203
        beta        = [3 5]; % m1 & m2 from table 2-1 DNV RP - C203
        loga        = [12.164 15.606]; % found from table DNV RP - C203 
        K           = 1./(10.^loga);
        DRFC_sx = cc2dam_2slope(RFC,beta,K,stresslim,thk,tref,k);

        Damage(n,alfa) = DRFC_sx; %%Damage 
    end
end    
ls.prop.damage_mat = Damage;
end
