%% ------------------------------------------------------------------------
% Writen for:   NTNU and Fred. Olsen
% Create by:    Marius Berg Maastad      
% 
% Aim:          Comparison for regular wave tests, decay tests, RAO tests,
%               and determination study for hydrodynamic and structural
%               coefficients
%
% Subfunction:  get_ls - Gets the experimental results from the 
%               experimental database
%               create_rao - Creates the RAO comparison for wave height 1m
%               2m and 3m
%               comp_reg_waves_2 - Compare experimental and numerical
%               regular wave for LPT formulation
%               comp_reg_waves_morison - Compare experimental and numerical
%               regular wave for Morison's formulation
%               comp_reg_waves_hp - Compare experimental and numerical
%               regular wave for LPT formulation W/ heave plates
%               comp_decay_2 - Comparison of decay tests
%               comp_decay_hp - Comparison of decay tests w/ heave plates
%
% ------------------------------------------------------------------------



clear all
close all
clc

% Get ls files
[tt, H_T] = get_ls;

% set global parameters
global par tt H_T

% set the time steps for either Morisons or LPT formulation
par.dt = [0.005; 0.2;0.1]; % Morison's dt
%par.dt = [0.005; 0.1;0.2]; % LPT dt
par.scale = 74;

% Variable for the various different scripts
var_rao = {'1m';'2m';'3m'};
var_lpt = {'reg_wave';};
var_mor = {'reg_wave';};
var_plate = {'reg_wave_plate';};
var_decay = {'decay_heave_l';'decay_heave_nl';'decay_pitch_l';'decay_pitch_nl';};
var_decay_plate = {'decay_heave_l_plate';'decay_heave_nl_plate'};

%% Comparison of RAO

%[res, prop_output,exp_sorted] = create_rao(var_rao);

%% Comparison of regular waves
% Select which comparison that shall be performed

%res = comp_reg_waves_2(var_lpt);
%comp_reg_waves_morison(var_mor);

%% Comparison of regular waves heave plates
% Select which comparison that shall be performed

%res = comp_reg_waves_hp(var_plate);

%% Comparison of decay

%comp_decay_2(var_decay);
%comp_decay_hp(var_decay_plate);



%% Create output from wave cases in RAO


% basepath = 'C:\Users\Marius\Dropbox\Master_thesis\doc\fig\comparison\rao';
% num = 25;
% fig = figure(100);
% plot(0.005*sqrt(74)*[1:length(exp_sorted{num,1}.ts.nacelle_heave_pos.y)],74*exp_sorted{num,1}.ts.nacelle_heave_pos.y)
% hold on
% plot(0.005*sqrt(74)*[1:length(exp_sorted{num,1}.ts.sea_elevation.y)],74*exp_sorted{num,1}.ts.sea_elevation.y)
% ylabel('[m]')
% %xlim([0 500])
% xlabel('Time [s]')
% legend({'Heave position [m]', 'Sea elevation [m]'},...
%     'Position',[0.656495670668909 0.840078132835683 0.24475432933109 0.0799218731545843],...
%     'FontSize',7)
% h = get(gca,'Children');
% set(gca,'Children', [h(2) h(1)] )
% id = sprintf('%.d',num);
% loc = fullfile(basepath, ['rao_h' id] );
% x0=5;
% y0=5;
% width=400;
% height=250;
% set(gcf,'units','points','position',[x0,y0,width,height]);
% hgexport(gcf,loc, hgexport('factorystyle'), 'Format', 'eps');
% hold off







