%% ------------------------------------------------------------------------
% Writen for:   NTNU and Fred. Olsen
% Create by:    Marius Berg Maastad      
% 
% Aim:          Post-process all results from tank test, and put it into a
% database, ordered by time stamps
%
% Subfunction:  read_file_for_input2 - sets the t start and t end for picking
%               out the time window for each regular wave case. 
%               read_regular_waves_ls - reads heave acceleration, pitch acceleration
%               sea elevation and time. Uses sub function to filter and
%               integrate the acceleration to displacement
%               readheavedecay_linear_ls - reads the heave decay tests
%               readpitchdecay_linear_ls - reads the pitch decay tests
%
% ------------------------------------------------------------------------

%% Directories
dirr = {'regular_wave/';'regular_wave_plate/';'heave_decay_linear/';'heave_decay_tests_nonlinear/';...
    'pitch_decay_linear/'; 'pitch_decay_nonlinear/';'With_added_mass_item/heave_lin/';...
    'With_added_mass_item/heave_nonlin/';'With_added_mass_item/pitch_lin/';...
    'With_added_mass_item/pitch_nonlin/';};
     
dec = {'blank1';'blank2';'heave_linear';'heave_nonlinear';'pitch_linear';'pitch_nonlinear';...
        'heave_linear_plate';'heave_nonlinear_plate';...
        'pitch_linear_plate';'pitch_nonlinear_plate';};     

%% fields
field1 = {'ts';'prop';};
field2 = {'nacelle_heave_acc_1';'nacelle_heave_acc_2'; ...
             'nacelle_heave_pos_1';'nacelle_heave_pos_2'; 'nacelle_heave_pos';...
             'nacelle_pitch';'sea_elevation';};
field3 = {'heave_pos';'heave_acc';};
field4 = {'pitch_pos';'heave_pos';'heave_acc';};
field5 = {'model_scale_H'; 'model_scale_T';}; 
field6 = {'full_scale_H'; 'full_scale_T';}; 

group = {'regular_wave';'regular_wave_plate';'decay_heave_linear';...
         'decay_heave_nonlinear';'decay_pitch_linear';'decay_pitch_nonlinear';...
         'decay_heave_linear_plate';'decay_heave_nonlinear_plate';'decay_pitch_linear_plate';
         'decay_pitch_nonlinear_plate'};
unit = {'m/s^2';'m/s^2'; 'm'; 'm'; 'm'; 'deg'; 'm';};
unit2 = {'m';'m/s^2'};
unit3 = {'deg';'m';'m/s^2'};

%% step variables 
% q: goes trough all directiories (dirr)
% w: Change for file number (within dirr)
% k: Change for wave train (with each test data)

%% run trough all files
for q = 1:length(dirr)
    for w = 1:length(dir(dirr{q}))-2
        ls = struct;    
        %All input files
        res = dir(dirr{q});
        str = res(w+2).name;
        
%For the regular wave tests        
         if q == 1 || q ==2
            %t_min and time_inst
            [t_min, time_inst] = read_file_for_input2(str);
            
           for k = 1:length(t_min)
                [per_osc, max_wave, acc_1, acc_2, eta1, eta2,eta_heave1, ...
                    theta, surface] = read_regular_waves_ls(dirr{q},time_inst,str,k);
                 var = [acc_1(:), acc_2(:), eta1(:), eta2(:), eta_heave1(:),...
                     theta(:), surface(:)];

                 for i = 1: length(field1)
                     ls.(field1{i}) = struct;
                 end

                 for i = 1: length(field2)
                     ls.ts.(field2{i}) = struct; 

                     ls.ts.(field2{i}).y = var(:,i);
                     ls.ts.(field2{i}).t = res(2+w).datenum;
                     ls.ts.(field2{i}).dt = 0.005;
                     ls.ts.(field2{i}).t1 = time_inst(k,1);
                     ls.ts.(field2{i}).t2 = time_inst(k,2);
                     ls.ts.(field2{i}).unit = unit{i};

                 end
                 
                 ch = fieldnames(ls.ts);
                    for i=1:length(ch)
                        if isnumeric(ls.ts.(ch{i}).y) && length(ls.ts.(ch{i}).y)>1
                            ls.ts.(ch{i}).stat.min = min(ls.ts.(ch{i}).y);
                            ls.ts.(ch{i}).stat.max = max(ls.ts.(ch{i}).y);
                            ls.ts.(ch{i}).stat.mean = mean(ls.ts.(ch{i}).y);
                            ls.ts.(ch{i}).stat.std = std(ls.ts.(ch{i}).y);
                        elseif length(ls.ts.(ch{i}).y)>1
                            ls.ts.(ch{i}).stat.mean = mean(ls.ts.(ch{i}).y);
                            ls.ts.(ch{i}).stat.cycles = cycles(ls.ts.(ch{i}).y);
                        else
                            ls.ts.(ch{i}).stat = struct([]);
                        end
                    end

                date1 = res(2+w).datenum;
                date2 = date1 + 0.005*time_inst(k,1)/24/3600;
                resTag = datestr(date2,'yyyy-mm-dd_HH-MM-SS');


               ls.prop.(field5{1}) = max_wave; 
               ls.prop.(field5{2}) = per_osc;
               ls.prop.(field6{1}) = max_wave*74; 
               ls.prop.(field6{2}) = per_osc*sqrt(74);
               ls.prop.info = 'The model test is carried out at Lilletanken at NTNU';
               ls.prop.tank_dim = '25 m x 2.8 m x 0.65 m';
               ls.prop.wave_maker = 'Pison wave maker';
               ls.prop.wave_measurer = 'Set up 1 m in front of the structure';
               ls.prop.model = 'Placed close to the wave maker, approximately 10 m from it';
               ls.prop.mooring_setup = 'The structure is set up of three horizontal springs working in the horizontal plane. The stiffness is determined by assuming a natural period of 60 s in full scale';
               ls.prop.nacelle_plates = 'Used 4 given metal plates as nacelle weight';
               ls.prop.nacelle_accelerometer = 'Attached two acceleromters on nacelle plate';
               ls.prop.nacelle_accelerometer_spacing = 0.155;
               ls.prop.spring_stiffness = 4; 
               ls.prop.spring_unit = 'N/m';
               ls.prop.scaling_factor = 74;
               
               ls.group = group(q);
               
               basepath = 'C:\Users\Marius\Dropbox\Sommerjobb_2016_FO\Modellforsok\Read_results\ls_resultater';
               save(fullfile(basepath,['' resTag]),'ls');
                
           end
                
            
%%For the decay tests  
         else
             if q == 3 || q == 4 || q == 7 || q == 8 
               [heave_pos, heave_acc, time2, nat_per] = readheavedecay_linear_ls(str,dirr{q}); 
               var = [heave_pos, heave_acc];

                 for i = 1: length(field1)
                     ls.(field1{i}) = struct;
                 end

                 for i = 1: length(field3)
                     ls.ts.(field3{i}) = struct; 
                     ls.ts.(field3{i}).y = var(:,i);
                     ls.ts.(field3{i}).time = time2;
                     ls.ts.(field3{i}).t = res(2+w).datenum;
                     ls.ts.(field3{i}).dt = 0.005;
                     ls.ts.(field3{i}).unit = unit2{i};

                 end
               
               ls.prop.natural_period = nat_per;
               ls.prop.info = 'The model test is carried out at Lilletanken at NTNU';
               ls.prop.tank_dim = '25 m x 2.8 m x 0.65 m';
               ls.prop.wave_maker = 'Pison wave maker';
               ls.prop.wave_measurer = 'Set up 1 m in front of the structure';
               ls.prop.model = 'Placed close to the wave maker, approximately 10 m from it';
               ls.prop.mooring_setup = 'The structure is set up of three horizontal springs working in the horizontal plane. The stiffness is determined by assuming a natural period of 60 s in full scale';
               ls.prop.nacelle_plates = 'Used 4 given metal plates as nacelle weight';
               ls.prop.nacelle_accelerometer = 'Attached two acceleromters on nacelle plate';
               ls.prop.nacelle_accelerometer_spacing = 0.155;
               ls.prop.spring_stiffness = 4; 
               ls.prop.spring_unit = 'N/m';
               ls.prop.scaling_factor = 74;
               
               ls.group = group(q);

               date1 = res(2+w).datenum;
               resTag = datestr(date1,'yyyy-mm-dd_HH-MM-SS');
               basepath = 'C:\Users\Marius\Dropbox\Sommerjobb_2016_FO\Modellforsok\Read_results\ls_resultater';
               save(fullfile(basepath,['' resTag]),'ls');                 
               
             elseif q == 5 || q == 6 || q == 9 || q == 10
                
                if q == 5 || q == 6
                    const = 0.05;
                else
                    const = 0.01;
                end
                
               [pitch_pos, heave_pos, heave_acc, time2, nat_per] = ...
                   readpitchdecay_linear_ls(str,dirr{q},const); 
               var = [pitch_pos, heave_pos, heave_acc];

                 for i = 1: length(field1)
                     ls.(field1{i}) = struct;
                 end

                 for i = 1: length(field4)
                     ls.ts.(field4{i}) = struct; 
                     ls.ts.(field4{i}).y = var(:,i);
                     ls.ts.(field4{i}).time = time2;
                     ls.ts.(field4{i}).t = res(2+w).datenum;
                     ls.ts.(field4{i}).dt = 0.005;
                     ls.ts.(field4{i}).unit = unit3{i};

                 end
               
               ls.prop.natural_period = nat_per;
               ls.prop.info = 'The model test is carried out at Lilletanken at NTNU';
               ls.prop.tank_dim = '25 m x 2.8 m x 0.65 m';
               ls.prop.wave_maker = 'Pison wave maker';
               ls.prop.wave_measurer = 'Set up 1 m in front of the structure';
               ls.prop.model = 'Placed close to the wave maker, approximately 10 m from it';
               ls.prop.mooring_setup = 'The structure is set up of three horizontal springs working in the horizontal plane. The stiffness is determined by assuming a natural period of 60 s in full scale';
               ls.prop.nacelle_plates = 'Used 4 given metal plates as nacelle weight';
               ls.prop.nacelle_accelerometer = 'Attached two acceleromters on nacelle plate';
               ls.prop.nacelle_accelerometer_spacing = 0.155;
               ls.prop.spring_stiffness = 4; 
               ls.prop.spring_unit = 'N/m';
               ls.prop.scaling_factor = 74;
               
               ls.group = group(q);

               date1 = res(2+w).datenum;
               resTag = datestr(date1,'yyyy-mm-dd_HH-MM-SS');
               basepath = 'C:\Users\Marius\Dropbox\Sommerjobb_2016_FO\Modellforsok\Read_results\ls_resultater';
               save(fullfile(basepath,['' resTag]),'ls');  
             else
             error('There is something wrong with the input')
             end

        end    
    end
end



   