%% ------------------------------------------------------------------------
% Writen for:   NTNU and Fred. Olsen
% Create by:    Marius Berg Maastad      
% 
% Aim:          Determine the FLS for 1 and 20 years w/ and without heave
%               plates
%
% Subfunction:  create_latex_table - Create output file for latex
%
% ------------------------------------------------------------------------

clear all
clc

%% Create path
base = {'whp'}; % 'whp' 'hp'

switch(base{1})
    case 'whp'
        path = {'irr_fatigue_lpt_m2';'irr_fatigue_lpt_m2_2';};
    case 'hp'
        path = {'irr_fatigue_lpt_m2_hp';'irr_fatigue_lpt_m2_2_hp'};
    otherwise 
        disp('wrong input')
end


%% Run Script
prob =[0.168; 0.227;0.132;0.178;0.098;0.025;0.021;0.005;0.057;0.015;...
    0.002;0.009;0.01;0.002;0.004; ];
sum(prob);

descr = {'Case';'Hs';'Tp';'U';'D_{1_{1hour}}';'D_{2_{1hour}}';'D_{1hour}';'Prob';'D_{1y}';'D_{20y}'};
%descr = {'Case';'Hs';'Tp';'U';'Damage1';'Prob';'Fatigue1y';'Fatigue20y'};

table = zeros(15,length(descr));

for k = 1: length(path)
    cd(path{k});
    folder = dir();
    folder(1:2) = [];
    for i = 1 : length(folder)
        res.ls(k).fatigue(i,1) = load(folder(i).name);
        res.ls(k).simId(i,1) = res.ls(k).fatigue(i,1).ls.prop.sim_report_set_n;
        yy.rotor(i) = res.ls(k).fatigue(i,1).ls.prop.rotor_operation_idle_on(1);
        yy.generator(i) = res.ls(k).fatigue(i,1).ls.ts.Generator_power.stat.mean; 
        yy.rotor_speed(i) = res.ls(k).fatigue(i,1).ls.ts.Rotor_speed_rpm.stat.mean; 
    end
    cd('../');
    
    
    
    [a1,b1] = sort(res.ls(k).simId);
    arrays= struct2cell(res.ls(k).fatigue)';
    res.ls(k).folder_sorted = arrays(b1,1); 
    res2.ls(k).table = zeros(length(res.ls(k).folder_sorted),7);
    
    for i = 1 : length(res.ls(k).folder_sorted)
        res2.ls(k).table(i,1) = i;
        res2.ls(k).table(i,2) = res.ls(k).folder_sorted{i,1}.prop.environment_sea_hs; 
        res2.ls(k).table(i,3) = res.ls(k).folder_sorted{i,1}.prop.environment_sea_tp;
        res2.ls(k).table(i,4) = res.ls(k).folder_sorted{i,1}.prop.environment_wind_speed;
        res2.ls(k).table(i,5) = res.ls(k).folder_sorted{i,1}.prop.damage_mat(1,1);
        res2.ls(k).table(i,6) = res.ls(k).folder_sorted{i,1}.prop.sim_solver_duration-400;
        res2.ls(k).table(i,7) = prob(i);
        res2.ls(k).table(i,8) = (res2.ls(k).table(i,5)*res2.ls(k).table(i,7)*365*24); 
        res2.ls(k).table(i,9) = (res2.ls(k).table(i,5)*res2.ls(k).table(i,7)*365*24*20);
       
    end
end

for i = 1:length(res.ls(1).folder_sorted)
    table(i,1) = i;
    table(i,2) = res.ls(1).folder_sorted{i,1}.prop.environment_sea_hs; 
    table(i,3) = res.ls(1).folder_sorted{i,1}.prop.environment_sea_tp;
    table(i,4) = res.ls(1).folder_sorted{i,1}.prop.environment_wind_speed;
    table(i,5) = res.ls(1).folder_sorted{i,1}.prop.damage_mat(1,1);
    table(i,6) = res.ls(2).folder_sorted{i,1}.prop.damage_mat(1,1);
    table(i,7) = ( table(i,5) + table(i,6) ) /2;
    table(i,8) = prob(i);
    table(i,9) = table(i,7)*table(i,8)*24*365; 
    table(i,10) = table(i,9)*20;
end

fatigue_1y = sum(table(:,9));
fatigue_20y = sum(table(:,10));

switch(base{1})
    case 'whp'
        cd = 'C:\Users\Marius\Dropbox\Master_thesis\doc\fatigue_table.tex';
        descr_2 = {'Fatigue damage at tower base, for structure without heave plates';'fig:fatigue_calc'};
    case 'hp'
        cd = 'C:\Users\Marius\Dropbox\Master_thesis\doc\fatigue_table_hp.tex';
        descr_2 = {'Fatigue damage at toer base,  for structure with heave plates';'fig:fatigue_calc_hp'};
end
create_latex_table (cd, descr_2, descr, table )
