%% ------------------------------------------------------------------------
% Writen for:   NTNU and Fred. Olsen
% Create by:    Marius Berg Maastad      
% 
% Aim:          Investigate the fatigue damage for different environmental
%               conditions
%
% Subfunction:  platmotions - Establish the spectrum for a certain input
%
% ------------------------------------------------------------------------


clear all
close all
clc

addpath(genpath('C:\Users\Marius\Dropbox\Windturbines\matlab_code_erin'));

%%
% Without Heave Plate
% 'fatigue_detailed_study' & 'fatigue_detailed_study_90deg'

% With Heave Plate
% 'fatigue_detailed_study_hp' & 'fatigue_detailed_study_90deg_hp' 

%% Set parameters
base = {'fatigue_detailed_study_90deg_hp'};

switch(base{1})
    case 'fatigue_detailed_study'
        h=1;
        path={'fatigue_detailed_study'};
        cd(path{1});
        dir2 = {'0deg'};
        dir4 = {'Tower base stress (F-A)'};
        dir6 = {'Without waves';'Initial';'Without wind';};
        fact = [10^-2,10^-4,10^-4];
        dir5 = {'(F-A)'};
        dir7 = {''};
        loop = [1;2;3];
    case 'fatigue_detailed_study_90deg'
        h=2;
        path={'fatigue_detailed_study_90deg'};
        cd(path{1});
        dir2 = {'90deg'};
        dir4 = {'Tower base stress (S-S)'};
        dir6 = {'Without waves';'Without wind';'Initial';};
        fact = [10^-2,10^-4,10^-4];
        dir5 = {'(S-S)'};
        dir7 = {''};
        loop = [1;3;2];
    case 'fatigue_detailed_study_hp'
        h=1;
        path={'fatigue_detailed_study_hp'};
        cd(path{1});
        dir2 = {'0deg'};
        dir3 = {'tower_base_Y_moment'};
        dir4 = {'Tower base stress (F-A)'};
        dir6 = {'Initial';'Without waves';'Without wind';};
        fact = [10^-4,10^-3,10^-4];
        dir5 = {'(F-A)'};
        loop = [2,1,3];
        dir7 = {'hp'};
    case 'fatigue_detailed_study_90deg_hp' 
        h=2;
        path={'fatigue_detailed_study_90deg_hp'};
        cd(path{1});
        dir2 = {'90deg'};
        dir3 = {'tower_base_Z_moment'};
        dir4 = {'Tower base stress (S-S)'};
        dir6 = {'Without waves';'Initial';'Without wind';};
        fact = [10^-3,10^-4,10^-4];
        dir5 = {'(S-S)'};
        loop = [1,2,3];
        dir7 = {'hp'};
    otherwise 
        disp ('Wrong input');
end

%% Run Script
k=1;
folder = dir();
folder(1:2) = [];
for i = 1:length(folder)
    ii = loop(k);
    load(folder(ii).name);
    
    cd('../')
    [Damage,Nx, sigma_tb] = calc_stress(ls);
    fin(i).Damage = Damage;
    fig = figure(1);
    dt = ls.ts.wave_eta_origin.dt;
    x(k).x = dt*[0:length(ls.ts.wave_eta_origin.y)-410/dt-1];
    y(k).y = sigma_tb(:,h); % 1= FA, 2 = SS
    plot(x(k).x,y(k).y);
    hold on
    
    p(k) = ls.ts.Rotor_speed_rpm.stat.mean * (2*pi/60); %rad/s
    S(k) = platmotions( ls, y(i).y);
    
    k=k+1;
    
    cd(path{1});
end

cd('../')

xlim([x(1).x(1) x(1).x(end)]);
ylim([-100 125]);
xlabel('Time [s]')
ylabel(sprintf('Stress %s at\n tower base [MPa]',dir5{1}));
legend({sprintf('  %s',dir6{loop(1)}),...
    sprintf('  %s',dir6{loop(2)}),...
    sprintf('  %s',dir6{loop(3)})},...
    'Position',[0.723215589472427 0.776396487835152 0.179284420988427 0.141103512164846],...
    'FontSize',7)

loc = fullfile('../../../doc/fig/comparison/fatigue_comparison/',['y_moment_comp' '_' dir7{1}  dir2{1} '.eps']);
x0=100;
y0=100;
width=500;
height=200;
h = get(gca,'Children');
if strcmp(base{1},'fatigue_detailed_study')
    child = [h(3) h(2) h(1)]; 
else
    child = [h(3) h(2) h(1)];
end
set(gca,'YTick',-100:25:125)
set(gca,'Children',child)
set(gcf,'units','points','position',[x0,y0,width,height])
hgexport(gcf,loc, hgexport('factorystyle'), 'Format', 'eps');
hold off
mean = [mean(y(1).y),mean(y(2).y)];

fig = figure(2);
w1 = S(1).w(1:1500);
spec1 = S(1).S(1:1500)*fact(loop(1));
w2 = S(2).w(1:1500);
spec2 = S(2).S(1:1500)*fact(loop(2));
w3 = S(3).w(1:1500);
spec3 = S(3).S(1:1500)*fact(loop(3));
plot(w1,spec1);
hold on
plot(w2,spec2);
hold on 
plot(w3,spec3);
xlim([w1(1) w1(end)])
%ylim([0 6])
xlabel('Frequency [rad/s]')
ylabel(sprintf('Spectral density for \n tower base stress [Nm^2/s] '))
legend({sprintf(' %s  (*%.e)',dir6{loop(1)},1/fact(loop(1)))...
    ,sprintf(' %s (*%.e)',dir6{loop(2)},1/fact(loop(2))),...
    sprintf(' %s (*%.e)',dir6{loop(3)},1/fact(loop(3)))},...
    'Position',[0.565434204853843 0.807117190268123 0.33599434345126 0.112882809731877],...
    'FontSize',7)

loc = fullfile('../../../doc/fig/comparison/fatigue_comparison/',['spectr_comp' '_' dir7{1} dir2{1} '.eps']);
x0=5;
y0=5;
width=350;
height=250;
h = get(gca,'Children');
if strcmp(base{1},'fatigue_detailed_study')
    child = [h(3) h(2) h(1)]; 
else
    child = [h(3) h(2) h(1)];
end
set(gca,'Children',child)
set(gcf,'units','points','position',[x0,y0,width,height])
hgexport(gcf,loc, hgexport('factorystyle'), 'Format', 'eps');
hold off